Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(832)

Unified Diff: Source/core/html/shadow/DateTimeFieldElement.h

Issue 106423003: [oilpan] Rename visit to mark. (Closed) Base URL: svn://svn.chromium.org/blink/branches/oilpan
Patch Set: Fix typo Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/html/shadow/DateTimeFieldElement.h
diff --git a/Source/core/html/shadow/DateTimeFieldElement.h b/Source/core/html/shadow/DateTimeFieldElement.h
index c88d94a8e527838c8d3329a090f45b13821ada83..f7ec3ece054a17177e1bfe090780847850e83e4b 100644
--- a/Source/core/html/shadow/DateTimeFieldElement.h
+++ b/Source/core/html/shadow/DateTimeFieldElement.h
@@ -60,12 +60,12 @@ public:
virtual bool isFieldOwnerReadOnly() const = 0;
virtual AtomicString localeIdentifier() const = 0;
// We can't pass FieldOwner pointer into Visitor::visit function
// directly because it does not coincide with the actual start of the object
// and visitor has to access object header. Thus we need a helper method
- // that would correctly adjust the pointer before passing it into the
+ // that will correctly adjust the pointer before passing it into the
// visitor.
- virtual void visitWith(Visitor*) const = 0;
+ virtual void adjustAndMark(Visitor*) const = 0;
virtual void trace(Visitor*) { }
};
@@ -113,7 +113,7 @@ private:
template<> class TraceTrait<DateTimeFieldElement::FieldOwner> {
public:
- static void visit(Visitor* visitor, const DateTimeFieldElement::FieldOwner* self) { self->visitWith(visitor); }
+ static void mark(Visitor* visitor, const DateTimeFieldElement::FieldOwner* self) { self->adjustAndMark(visitor); }
static intptr_t getTypeMarker() { return 0; }
static void checkTypeMarker(Visitor*, const DateTimeFieldElement::FieldOwner*) { }
static void trace(Visitor* visitor, void* self) { static_cast<DateTimeFieldElement::FieldOwner*>(self)->trace(visitor); }
@@ -60,12 +60,12 @@ public:
virtual bool isFieldOwnerReadOnly() const = 0;
virtual AtomicString localeIdentifier() const = 0;
- // We can't pass FieldOwner pointer into Visitor::visit function
+ // We can't pass FieldOwner pointer into Visitor::mark function
// directly because it does not coincide with the actual start of the object
// and visitor has to access object header. Thus we need a helper method

Powered by Google App Engine
This is Rietveld 408576698